Name:          elasticsearch
Version:       2.4.1
Release:       1%{?dist}
Summary:       Open source, flexible, distributed search and analytics engine
License:       ASL 2.0
URL:           http://www.elasticsearch.org/
Source0:       https://download.elastic.co/%{name}/release/org/%{name}/distribution/tar/%{name}/%{version}/%{name}-%{version}.tar.gz
Source1:       elasticsearch-init
Source2:       %{name}.service
Source3:       elasticsearch-sysconfig
Source4:       elasticsearch.conf-sysctl
Source5:       elasticsearch.conf-tmpfiles
Source6:       elasticsearch-systemd-pre-exec
BuildRequires:    systemd
Requires:         java

Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
# user and group creation
Requires(pre): shadow-utils

BuildArch:     noarch

%description
Elasticsearch is a search server based on Lucene. It provides a distributed,
multitenant-capable full-text search engine with a RESTful web interface and
schema-free JSON documents. Elasticsearch is developed in Java and is released
as open source under the terms of the Apache License.

It is a flexible and powerful open source, distributed, real-time
search and analytics engine.

Architected from the ground up for use in distributed environments where
reliability and scalability are must haves, Elasticsearch gives you the ability
to move easily beyond simple full-text search.

Through its robust set of APIs and query DSLs, plus clients for the most popular
programming languages, Elasticsearch delivers on the near limitless promises of
search technology.

%prep
%autosetup -n %{name}-%{version} -p0

%build
true

%install
%{__mkdir} -p %{buildroot}/var/run/%{name}
%{__mkdir} -p %{buildroot}/var/log/%{name}
%{__mkdir} -p %{buildroot}/%{_sharedstatedir}/%{name}

# config #TODO
%{__mkdir} -p %{buildroot}/%{_sysconfdir}/%{name}/scripts
%{__install} -m 644 config/%{name}.yml %{buildroot}%{_sysconfdir}/%{name}/
%{__install} -m 644 config/logging.yml %{buildroot}%{_sysconfdir}/%{name}/

# init.d
%{__mkdir} -p %{buildroot}/%{_sysconfdir}/init.d
%{__install} -D -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/init.d/%{name}

# systemd
%{__mkdir} -p %{buildroot}/%{_unitdir}
%{__install} -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service

# sysconfig
%{__mkdir} -p %{buildroot}/%{_sysconfdir}/sysconfig
%{__install} -m 755 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

%{__mkdir} -p %{buildroot}/%{_sysctldir}
%{__install} -m 755 %{SOURCE4} %{buildroot}/%{_sysctldir}/%{name}.conf

%{__mkdir} -p %{buildroot}/%{_tmpfilesdir}
%{__install} -m 755 %{SOURCE5} %{buildroot}/%{_tmpfilesdir}/%{name}.conf

# sources
%{__mkdir} -p %{buildroot}/%{_datadir}/%{name}/plugins/
%{__cp} -r {bin,lib,modules,LICENSE.txt,NOTICE.txt,README.textile} %{buildroot}/%{_datadir}/%{name}
%{__install} -m 755 %{SOURCE6} %{buildroot}/%{_datadir}/%{name}/bin/
find %{buildroot}/%{_datadir}/%{name}/bin/ -name *.exe -delete
find %{buildroot}/%{_datadir}/%{name}/bin/ -name *.bat -delete

%pre
# add the elasticsearch user and group
getent group  %{name} >/dev/null || %{_sbindir}/groupadd -r %{name}
getent passwd %{name} >/dev/null || %{_sbindir}/useradd -r -g %{name} -d %{_sharedstatedir}/%{name} -s %{_sbindir}/nologin \
    -c "Elastic Search shared service user" elasticsearch
exit 0

%post
# install but don't activate
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service


%postun
%systemd_postun_with_restart %{name}.service
# %%systemd_postun %%{name}.service

%files
%dir /var/run/%{name}
%dir /var/log/%{name}
%dir %{_sharedstatedir}/%{name}
%dir %{_sysconfdir}/%{name}/scripts
%config(noreplace) %{_sysconfdir}/init.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/logging.yml
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.yml
/%{_sysctldir}/%{name}.conf
/%{_unitdir}/%{name}.service
/%{_tmpfilesdir}/%{name}.conf
%attr(0755, %{name}, %{name}) %{_datadir}/%{name}/bin/
%attr(0755, %{name}, %{name}) %{_datadir}/%{name}/lib/
%attr(0755, %{name}, %{name}) %{_datadir}/%{name}/modules/
%attr(0755, %{name}, %{name}) %{_datadir}/%{name}/plugins/
%license %{_datadir}/%{name}/LICENSE.txt
%license %{_datadir}/%{name}/NOTICE.txt
%doc %{_datadir}/%{name}/README.textile

%changelog
* Wed Oct 19 2016 <livy.ge@oracle.com>  2.4.1-1
- Include upstream 2.4.1
